# This file was auto-generated by Fern from our API Definition.

from ...core.unchecked_base_model import UncheckedBaseModel
from .templates_create_agents_from_template_response_agents_item_sources_item_embedding_config_embedding_endpoint_type import (
    TemplatesCreateAgentsFromTemplateResponseAgentsItemSourcesItemEmbeddingConfigEmbeddingEndpointType,
)
import typing
from .templates_create_agents_from_template_response_agents_item_sources_item_embedding_config_embedding_endpoint import (
    TemplatesCreateAgentsFromTemplateResponseAgentsItemSourcesItemEmbeddingConfigEmbeddingEndpoint,
)
from .templates_create_agents_from_template_response_agents_item_sources_item_embedding_config_embedding_chunk_size import (
    TemplatesCreateAgentsFromTemplateResponseAgentsItemSourcesItemEmbeddingConfigEmbeddingChunkSize,
)
from .templates_create_agents_from_template_response_agents_item_sources_item_embedding_config_handle import (
    TemplatesCreateAgentsFromTemplateResponseAgentsItemSourcesItemEmbeddingConfigHandle,
)
from .templates_create_agents_from_template_response_agents_item_sources_item_embedding_config_azure_endpoint import (
    TemplatesCreateAgentsFromTemplateResponseAgentsItemSourcesItemEmbeddingConfigAzureEndpoint,
)
from .templates_create_agents_from_template_response_agents_item_sources_item_embedding_config_azure_version import (
    TemplatesCreateAgentsFromTemplateResponseAgentsItemSourcesItemEmbeddingConfigAzureVersion,
)
from .templates_create_agents_from_template_response_agents_item_sources_item_embedding_config_azure_deployment import (
    TemplatesCreateAgentsFromTemplateResponseAgentsItemSourcesItemEmbeddingConfigAzureDeployment,
)
from ...core.pydantic_utilities import IS_PYDANTIC_V2
import pydantic


class TemplatesCreateAgentsFromTemplateResponseAgentsItemSourcesItemEmbeddingConfig(UncheckedBaseModel):
    embedding_endpoint_type: (
        TemplatesCreateAgentsFromTemplateResponseAgentsItemSourcesItemEmbeddingConfigEmbeddingEndpointType
    )
    embedding_endpoint: typing.Optional[
        TemplatesCreateAgentsFromTemplateResponseAgentsItemSourcesItemEmbeddingConfigEmbeddingEndpoint
    ] = None
    embedding_model: str
    embedding_dim: float
    embedding_chunk_size: typing.Optional[
        TemplatesCreateAgentsFromTemplateResponseAgentsItemSourcesItemEmbeddingConfigEmbeddingChunkSize
    ] = None
    handle: typing.Optional[TemplatesCreateAgentsFromTemplateResponseAgentsItemSourcesItemEmbeddingConfigHandle] = None
    azure_endpoint: typing.Optional[
        TemplatesCreateAgentsFromTemplateResponseAgentsItemSourcesItemEmbeddingConfigAzureEndpoint
    ] = None
    azure_version: typing.Optional[
        TemplatesCreateAgentsFromTemplateResponseAgentsItemSourcesItemEmbeddingConfigAzureVersion
    ] = None
    azure_deployment: typing.Optional[
        TemplatesCreateAgentsFromTemplateResponseAgentsItemSourcesItemEmbeddingConfigAzureDeployment
    ] = None

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
