# This file was auto-generated by Fern from our API Definition.

import typing
from .tool_call import ToolCall
from .tool_call_delta import ToolCallDelta

ToolCallMessageToolCall = typing.Union[ToolCall, ToolCallDelta]
