# This file was auto-generated by Fern from our API Definition.

import typing

AgentsSearchResponseAgentsItemToolRulesItemItemChildOutputMappingRequireOutputMapping = typing.Union[
    bool, typing.Optional[typing.Any]
]
