# This file was auto-generated by Fern from our API Definition.

from ...core.unchecked_base_model import UncheckedBaseModel
from .agents_search_response_agents_item_sources_item_embedding_config_embedding_endpoint_type import (
    AgentsSearchResponseAgentsItemSourcesItemEmbeddingConfigEmbeddingEndpointType,
)
import typing
from .agents_search_response_agents_item_sources_item_embedding_config_embedding_endpoint import (
    AgentsSearchResponseAgentsItemSourcesItemEmbeddingConfigEmbeddingEndpoint,
)
from .agents_search_response_agents_item_sources_item_embedding_config_embedding_chunk_size import (
    AgentsSearchResponseAgentsItemSourcesItemEmbeddingConfigEmbeddingChunkSize,
)
from .agents_search_response_agents_item_sources_item_embedding_config_handle import (
    AgentsSearchResponseAgentsItemSourcesItemEmbeddingConfigHandle,
)
from .agents_search_response_agents_item_sources_item_embedding_config_azure_endpoint import (
    AgentsSearchResponseAgentsItemSourcesItemEmbeddingConfigAzureEndpoint,
)
from .agents_search_response_agents_item_sources_item_embedding_config_azure_version import (
    AgentsSearchResponseAgentsItemSourcesItemEmbeddingConfigAzureVersion,
)
from .agents_search_response_agents_item_sources_item_embedding_config_azure_deployment import (
    AgentsSearchResponseAgentsItemSourcesItemEmbeddingConfigAzureDeployment,
)
from ...core.pydantic_utilities import IS_PYDANTIC_V2
import pydantic


class AgentsSearchResponseAgentsItemSourcesItemEmbeddingConfig(UncheckedBaseModel):
    embedding_endpoint_type: AgentsSearchResponseAgentsItemSourcesItemEmbeddingConfigEmbeddingEndpointType
    embedding_endpoint: typing.Optional[AgentsSearchResponseAgentsItemSourcesItemEmbeddingConfigEmbeddingEndpoint] = (
        None
    )
    embedding_model: str
    embedding_dim: float
    embedding_chunk_size: typing.Optional[
        AgentsSearchResponseAgentsItemSourcesItemEmbeddingConfigEmbeddingChunkSize
    ] = None
    handle: typing.Optional[AgentsSearchResponseAgentsItemSourcesItemEmbeddingConfigHandle] = None
    azure_endpoint: typing.Optional[AgentsSearchResponseAgentsItemSourcesItemEmbeddingConfigAzureEndpoint] = None
    azure_version: typing.Optional[AgentsSearchResponseAgentsItemSourcesItemEmbeddingConfigAzureVersion] = None
    azure_deployment: typing.Optional[AgentsSearchResponseAgentsItemSourcesItemEmbeddingConfigAzureDeployment] = None

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
