# This file was auto-generated by Fern from our API Definition.

import typing
from .templates_create_agents_from_template_response_agents_item_tool_rules_item_item_children import (
    TemplatesCreateAgentsFromTemplateResponseAgentsItemToolRulesItemItemChildren,
)
from .templates_create_agents_from_template_response_agents_item_tool_rules_item_item_one import (
    TemplatesCreateAgentsFromTemplateResponseAgentsItemToolRulesItemItemOne,
)
from .templates_create_agents_from_template_response_agents_item_tool_rules_item_item_two import (
    TemplatesCreateAgentsFromTemplateResponseAgentsItemToolRulesItemItemTwo,
)
from .templates_create_agents_from_template_response_agents_item_tool_rules_item_item_child_output_mapping import (
    TemplatesCreateAgentsFromTemplateResponseAgentsItemToolRulesItemItemChildOutputMapping,
)

TemplatesCreateAgentsFromTemplateResponseAgentsItemToolRulesItemItem = typing.Union[
    TemplatesCreateAgentsFromTemplateResponseAgentsItemToolRulesItemItemChildren,
    TemplatesCreateAgentsFromTemplateResponseAgentsItemToolRulesItemItemOne,
    TemplatesCreateAgentsFromTemplateResponseAgentsItemToolRulesItemItemTwo,
    TemplatesCreateAgentsFromTemplateResponseAgentsItemToolRulesItemItemChildOutputMapping,
]
