# This file was auto-generated by Fern from our API Definition.

import typing
from .agents_search_response_agents_item_tools_item_organization_id_item import (
    AgentsSearchResponseAgentsItemToolsItemOrganizationIdItem,
)

AgentsSearchResponseAgentsItemToolsItemOrganizationId = typing.Union[
    str, typing.Optional[str], typing.List[typing.Optional[AgentsSearchResponseAgentsItemToolsItemOrganizationIdItem]]
]
