# This file was auto-generated by Fern from our API Definition.

import typing

TemplatesCreateAgentsFromTemplateResponseAgentsItemSourcesItemDescriptionItem = typing.Union[str, typing.Optional[str]]
