# This file was auto-generated by Fern from our API Definition.

import typing
from .agents_search_response_agents_item_sources_item_embedding_config_embedding_chunk_size_item import (
    AgentsSearchResponseAgentsItemSourcesItemEmbeddingConfigEmbeddingChunkSizeItem,
)

AgentsSearchResponseAgentsItemSourcesItemEmbeddingConfigEmbeddingChunkSize = typing.Union[
    float,
    typing.Optional[str],
    typing.List[typing.Optional[AgentsSearchResponseAgentsItemSourcesItemEmbeddingConfigEmbeddingChunkSizeItem]],
    typing.Optional[typing.Any],
]
