# This file was auto-generated by Fern from our API Definition.

import typing
from .templates_create_agents_from_template_response_agents_item_tool_rules_item_item import (
    TemplatesCreateAgentsFromTemplateResponseAgentsItemToolRulesItemItem,
)

TemplatesCreateAgentsFromTemplateResponseAgentsItemToolRulesItem = typing.Union[
    typing.List[TemplatesCreateAgentsFromTemplateResponseAgentsItemToolRulesItemItem], typing.Optional[str]
]
