# This file was auto-generated by Fern from our API Definition.

import typing

TemplatesCreateAgentsFromTemplateResponseAgentsItemToolRulesItemItemTwoType = typing.Union[
    typing.Literal["exit_loop"], typing.Optional[typing.Any]
]
