# This file was auto-generated by Fern from our API Definition.

import typing

AgentsSearchResponseAgentsItemMemoryBlocksItemMetadataItem = typing.Union[
    typing.Optional[typing.Any], typing.Optional[str]
]
