# This file was auto-generated by Fern from our API Definition.

from ...core.unchecked_base_model import UncheckedBaseModel
import typing
from .templates_create_agents_from_template_response_agents_item_tool_exec_environment_variables_item_created_by_id import (
    TemplatesCreateAgentsFromTemplateResponseAgentsItemToolExecEnvironmentVariablesItemCreatedById,
)
from .templates_create_agents_from_template_response_agents_item_tool_exec_environment_variables_item_last_updated_by_id import (
    TemplatesCreateAgentsFromTemplateResponseAgentsItemToolExecEnvironmentVariablesItemLastUpdatedById,
)
from .templates_create_agents_from_template_response_agents_item_tool_exec_environment_variables_item_created_at import (
    TemplatesCreateAgentsFromTemplateResponseAgentsItemToolExecEnvironmentVariablesItemCreatedAt,
)
from .templates_create_agents_from_template_response_agents_item_tool_exec_environment_variables_item_updated_at import (
    TemplatesCreateAgentsFromTemplateResponseAgentsItemToolExecEnvironmentVariablesItemUpdatedAt,
)
from .templates_create_agents_from_template_response_agents_item_tool_exec_environment_variables_item_id import (
    TemplatesCreateAgentsFromTemplateResponseAgentsItemToolExecEnvironmentVariablesItemId,
)
from .templates_create_agents_from_template_response_agents_item_tool_exec_environment_variables_item_description import (
    TemplatesCreateAgentsFromTemplateResponseAgentsItemToolExecEnvironmentVariablesItemDescription,
)
from .templates_create_agents_from_template_response_agents_item_tool_exec_environment_variables_item_organization_id import (
    TemplatesCreateAgentsFromTemplateResponseAgentsItemToolExecEnvironmentVariablesItemOrganizationId,
)
from ...core.pydantic_utilities import IS_PYDANTIC_V2
import pydantic


class TemplatesCreateAgentsFromTemplateResponseAgentsItemToolExecEnvironmentVariablesItem(UncheckedBaseModel):
    created_by_id: typing.Optional[
        TemplatesCreateAgentsFromTemplateResponseAgentsItemToolExecEnvironmentVariablesItemCreatedById
    ] = None
    last_updated_by_id: typing.Optional[
        TemplatesCreateAgentsFromTemplateResponseAgentsItemToolExecEnvironmentVariablesItemLastUpdatedById
    ] = None
    created_at: typing.Optional[
        TemplatesCreateAgentsFromTemplateResponseAgentsItemToolExecEnvironmentVariablesItemCreatedAt
    ] = None
    updated_at: typing.Optional[
        TemplatesCreateAgentsFromTemplateResponseAgentsItemToolExecEnvironmentVariablesItemUpdatedAt
    ] = None
    id: typing.Optional[TemplatesCreateAgentsFromTemplateResponseAgentsItemToolExecEnvironmentVariablesItemId] = None
    key: str
    value: str
    description: typing.Optional[
        TemplatesCreateAgentsFromTemplateResponseAgentsItemToolExecEnvironmentVariablesItemDescription
    ] = None
    organization_id: typing.Optional[
        TemplatesCreateAgentsFromTemplateResponseAgentsItemToolExecEnvironmentVariablesItemOrganizationId
    ] = None
    agent_id: str

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
