# This file was auto-generated by Fern from our API Definition.

from ...core.unchecked_base_model import UncheckedBaseModel
from .agents_search_response_agents_item_llm_config_model_endpoint_type import (
    AgentsSearchResponseAgentsItemLlmConfigModelEndpointType,
)
import typing
from .agents_search_response_agents_item_llm_config_model_endpoint import (
    AgentsSearchResponseAgentsItemLlmConfigModelEndpoint,
)
from .agents_search_response_agents_item_llm_config_model_wrapper import (
    AgentsSearchResponseAgentsItemLlmConfigModelWrapper,
)
from .agents_search_response_agents_item_llm_config_put_inner_thoughts_in_kwargs import (
    AgentsSearchResponseAgentsItemLlmConfigPutInnerThoughtsInKwargs,
)
from .agents_search_response_agents_item_llm_config_handle import AgentsSearchResponseAgentsItemLlmConfigHandle
from .agents_search_response_agents_item_llm_config_temperature import (
    AgentsSearchResponseAgentsItemLlmConfigTemperature,
)
from .agents_search_response_agents_item_llm_config_max_tokens import AgentsSearchResponseAgentsItemLlmConfigMaxTokens
from ...core.pydantic_utilities import IS_PYDANTIC_V2
import pydantic


class AgentsSearchResponseAgentsItemLlmConfig(UncheckedBaseModel):
    model: str
    model_endpoint_type: AgentsSearchResponseAgentsItemLlmConfigModelEndpointType
    model_endpoint: typing.Optional[AgentsSearchResponseAgentsItemLlmConfigModelEndpoint] = None
    model_wrapper: typing.Optional[AgentsSearchResponseAgentsItemLlmConfigModelWrapper] = None
    context_window: float
    put_inner_thoughts_in_kwargs: typing.Optional[AgentsSearchResponseAgentsItemLlmConfigPutInnerThoughtsInKwargs] = (
        None
    )
    handle: typing.Optional[AgentsSearchResponseAgentsItemLlmConfigHandle] = None
    temperature: typing.Optional[AgentsSearchResponseAgentsItemLlmConfigTemperature] = None
    max_tokens: typing.Optional[AgentsSearchResponseAgentsItemLlmConfigMaxTokens] = None

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
