# This file was auto-generated by Fern from our API Definition.

from .types import (
    AgentsSearchRequestSearchItem,
    AgentsSearchRequestSearchItemField,
    AgentsSearchRequestSearchItemOne,
    AgentsSearchRequestSearchItemOneOperator,
    AgentsSearchRequestSearchItemZero,
    AgentsSearchResponse,
    AgentsSearchResponseAgentsItem,
    AgentsSearchResponseAgentsItemAgentType,
    AgentsSearchResponseAgentsItemBaseTemplateId,
    AgentsSearchResponseAgentsItemBaseTemplateIdItem,
    AgentsSearchResponseAgentsItemCreatedAt,
    AgentsSearchResponseAgentsItemCreatedAtItem,
    AgentsSearchResponseAgentsItemCreatedById,
    AgentsSearchResponseAgentsItemCreatedByIdItem,
    AgentsSearchResponseAgentsItemDescription,
    AgentsSearchResponseAgentsItemDescriptionItem,
    AgentsSearchResponseAgentsItemEmbeddingConfig,
    AgentsSearchResponseAgentsItemEmbeddingConfigAzureDeployment,
    AgentsSearchResponseAgentsItemEmbeddingConfigAzureDeploymentItem,
    AgentsSearchResponseAgentsItemEmbeddingConfigAzureEndpoint,
    AgentsSearchResponseAgentsItemEmbeddingConfigAzureEndpointItem,
    AgentsSearchResponseAgentsItemEmbeddingConfigAzureVersion,
    AgentsSearchResponseAgentsItemEmbeddingConfigAzureVersionItem,
    AgentsSearchResponseAgentsItemEmbeddingConfigEmbeddingChunkSize,
    AgentsSearchResponseAgentsItemEmbeddingConfigEmbeddingChunkSizeItem,
    AgentsSearchResponseAgentsItemEmbeddingConfigEmbeddingEndpoint,
    AgentsSearchResponseAgentsItemEmbeddingConfigEmbeddingEndpointItem,
    AgentsSearchResponseAgentsItemEmbeddingConfigEmbeddingEndpointType,
    AgentsSearchResponseAgentsItemEmbeddingConfigHandle,
    AgentsSearchResponseAgentsItemEmbeddingConfigHandleItem,
    AgentsSearchResponseAgentsItemLastUpdatedById,
    AgentsSearchResponseAgentsItemLastUpdatedByIdItem,
    AgentsSearchResponseAgentsItemLlmConfig,
    AgentsSearchResponseAgentsItemLlmConfigHandle,
    AgentsSearchResponseAgentsItemLlmConfigHandleItem,
    AgentsSearchResponseAgentsItemLlmConfigMaxTokens,
    AgentsSearchResponseAgentsItemLlmConfigMaxTokensItem,
    AgentsSearchResponseAgentsItemLlmConfigModelEndpoint,
    AgentsSearchResponseAgentsItemLlmConfigModelEndpointItem,
    AgentsSearchResponseAgentsItemLlmConfigModelEndpointType,
    AgentsSearchResponseAgentsItemLlmConfigModelWrapper,
    AgentsSearchResponseAgentsItemLlmConfigModelWrapperItem,
    AgentsSearchResponseAgentsItemLlmConfigPutInnerThoughtsInKwargs,
    AgentsSearchResponseAgentsItemLlmConfigPutInnerThoughtsInKwargsItem,
    AgentsSearchResponseAgentsItemLlmConfigTemperature,
    AgentsSearchResponseAgentsItemMemory,
    AgentsSearchResponseAgentsItemMemoryBlocksItem,
    AgentsSearchResponseAgentsItemMemoryBlocksItemCreatedById,
    AgentsSearchResponseAgentsItemMemoryBlocksItemCreatedByIdItem,
    AgentsSearchResponseAgentsItemMemoryBlocksItemDescription,
    AgentsSearchResponseAgentsItemMemoryBlocksItemDescriptionItem,
    AgentsSearchResponseAgentsItemMemoryBlocksItemId,
    AgentsSearchResponseAgentsItemMemoryBlocksItemIsTemplate,
    AgentsSearchResponseAgentsItemMemoryBlocksItemLabel,
    AgentsSearchResponseAgentsItemMemoryBlocksItemLabelItem,
    AgentsSearchResponseAgentsItemMemoryBlocksItemLastUpdatedById,
    AgentsSearchResponseAgentsItemMemoryBlocksItemLastUpdatedByIdItem,
    AgentsSearchResponseAgentsItemMemoryBlocksItemLimit,
    AgentsSearchResponseAgentsItemMemoryBlocksItemMetadata,
    AgentsSearchResponseAgentsItemMemoryBlocksItemMetadataItem,
    AgentsSearchResponseAgentsItemMemoryBlocksItemName,
    AgentsSearchResponseAgentsItemMemoryBlocksItemNameItem,
    AgentsSearchResponseAgentsItemMemoryBlocksItemOrganizationId,
    AgentsSearchResponseAgentsItemMemoryBlocksItemOrganizationIdItem,
    AgentsSearchResponseAgentsItemMemoryPromptTemplate,
    AgentsSearchResponseAgentsItemMessageIds,
    AgentsSearchResponseAgentsItemMessageIdsItem,
    AgentsSearchResponseAgentsItemMetadata,
    AgentsSearchResponseAgentsItemMetadataItem,
    AgentsSearchResponseAgentsItemOrganizationId,
    AgentsSearchResponseAgentsItemOrganizationIdItem,
    AgentsSearchResponseAgentsItemProjectId,
    AgentsSearchResponseAgentsItemProjectIdItem,
    AgentsSearchResponseAgentsItemSourcesItem,
    AgentsSearchResponseAgentsItemSourcesItemCreatedAt,
    AgentsSearchResponseAgentsItemSourcesItemCreatedAtItem,
    AgentsSearchResponseAgentsItemSourcesItemCreatedById,
    AgentsSearchResponseAgentsItemSourcesItemCreatedByIdItem,
    AgentsSearchResponseAgentsItemSourcesItemDescription,
    AgentsSearchResponseAgentsItemSourcesItemDescriptionItem,
    AgentsSearchResponseAgentsItemSourcesItemEmbeddingConfig,
    AgentsSearchResponseAgentsItemSourcesItemEmbeddingConfigAzureDeployment,
    AgentsSearchResponseAgentsItemSourcesItemEmbeddingConfigAzureDeploymentItem,
    AgentsSearchResponseAgentsItemSourcesItemEmbeddingConfigAzureEndpoint,
    AgentsSearchResponseAgentsItemSourcesItemEmbeddingConfigAzureEndpointItem,
    AgentsSearchResponseAgentsItemSourcesItemEmbeddingConfigAzureVersion,
    AgentsSearchResponseAgentsItemSourcesItemEmbeddingConfigAzureVersionItem,
    AgentsSearchResponseAgentsItemSourcesItemEmbeddingConfigEmbeddingChunkSize,
    AgentsSearchResponseAgentsItemSourcesItemEmbeddingConfigEmbeddingChunkSizeItem,
    AgentsSearchResponseAgentsItemSourcesItemEmbeddingConfigEmbeddingEndpoint,
    AgentsSearchResponseAgentsItemSourcesItemEmbeddingConfigEmbeddingEndpointItem,
    AgentsSearchResponseAgentsItemSourcesItemEmbeddingConfigEmbeddingEndpointType,
    AgentsSearchResponseAgentsItemSourcesItemEmbeddingConfigHandle,
    AgentsSearchResponseAgentsItemSourcesItemEmbeddingConfigHandleItem,
    AgentsSearchResponseAgentsItemSourcesItemId,
    AgentsSearchResponseAgentsItemSourcesItemLastUpdatedById,
    AgentsSearchResponseAgentsItemSourcesItemLastUpdatedByIdItem,
    AgentsSearchResponseAgentsItemSourcesItemMetadata,
    AgentsSearchResponseAgentsItemSourcesItemMetadataItem,
    AgentsSearchResponseAgentsItemSourcesItemOrganizationId,
    AgentsSearchResponseAgentsItemSourcesItemOrganizationIdItem,
    AgentsSearchResponseAgentsItemSourcesItemUpdatedAt,
    AgentsSearchResponseAgentsItemSourcesItemUpdatedAtItem,
    AgentsSearchResponseAgentsItemTemplateId,
    AgentsSearchResponseAgentsItemTemplateIdItem,
    AgentsSearchResponseAgentsItemToolExecEnvironmentVariables,
    AgentsSearchResponseAgentsItemToolExecEnvironmentVariablesItem,
    AgentsSearchResponseAgentsItemToolExecEnvironmentVariablesItemCreatedAt,
    AgentsSearchResponseAgentsItemToolExecEnvironmentVariablesItemCreatedAtItem,
    AgentsSearchResponseAgentsItemToolExecEnvironmentVariablesItemCreatedById,
    AgentsSearchResponseAgentsItemToolExecEnvironmentVariablesItemCreatedByIdItem,
    AgentsSearchResponseAgentsItemToolExecEnvironmentVariablesItemDescription,
    AgentsSearchResponseAgentsItemToolExecEnvironmentVariablesItemDescriptionItem,
    AgentsSearchResponseAgentsItemToolExecEnvironmentVariablesItemId,
    AgentsSearchResponseAgentsItemToolExecEnvironmentVariablesItemLastUpdatedById,
    AgentsSearchResponseAgentsItemToolExecEnvironmentVariablesItemLastUpdatedByIdItem,
    AgentsSearchResponseAgentsItemToolExecEnvironmentVariablesItemOrganizationId,
    AgentsSearchResponseAgentsItemToolExecEnvironmentVariablesItemOrganizationIdItem,
    AgentsSearchResponseAgentsItemToolExecEnvironmentVariablesItemUpdatedAt,
    AgentsSearchResponseAgentsItemToolExecEnvironmentVariablesItemUpdatedAtItem,
    AgentsSearchResponseAgentsItemToolRules,
    AgentsSearchResponseAgentsItemToolRulesItem,
    AgentsSearchResponseAgentsItemToolRulesItemChildOutputMapping,
    AgentsSearchResponseAgentsItemToolRulesItemChildOutputMappingDefaultChild,
    AgentsSearchResponseAgentsItemToolRulesItemChildOutputMappingDefaultChildItem,
    AgentsSearchResponseAgentsItemToolRulesItemChildOutputMappingRequireOutputMapping,
    AgentsSearchResponseAgentsItemToolRulesItemChildOutputMappingType,
    AgentsSearchResponseAgentsItemToolRulesItemChildren,
    AgentsSearchResponseAgentsItemToolRulesItemChildrenType,
    AgentsSearchResponseAgentsItemToolRulesItemItem,
    AgentsSearchResponseAgentsItemToolRulesItemItemChildOutputMapping,
    AgentsSearchResponseAgentsItemToolRulesItemItemChildOutputMappingDefaultChild,
    AgentsSearchResponseAgentsItemToolRulesItemItemChildOutputMappingDefaultChildItem,
    AgentsSearchResponseAgentsItemToolRulesItemItemChildOutputMappingRequireOutputMapping,
    AgentsSearchResponseAgentsItemToolRulesItemItemChildOutputMappingType,
    AgentsSearchResponseAgentsItemToolRulesItemItemChildren,
    AgentsSearchResponseAgentsItemToolRulesItemItemChildrenType,
    AgentsSearchResponseAgentsItemToolRulesItemItemOne,
    AgentsSearchResponseAgentsItemToolRulesItemItemOneType,
    AgentsSearchResponseAgentsItemToolRulesItemItemTwo,
    AgentsSearchResponseAgentsItemToolRulesItemItemTwoType,
    AgentsSearchResponseAgentsItemToolRulesItemOne,
    AgentsSearchResponseAgentsItemToolRulesItemOneType,
    AgentsSearchResponseAgentsItemToolRulesItemTwo,
    AgentsSearchResponseAgentsItemToolRulesItemTwoType,
    AgentsSearchResponseAgentsItemToolsItem,
    AgentsSearchResponseAgentsItemToolsItemCreatedById,
    AgentsSearchResponseAgentsItemToolsItemCreatedByIdItem,
    AgentsSearchResponseAgentsItemToolsItemDescription,
    AgentsSearchResponseAgentsItemToolsItemDescriptionItem,
    AgentsSearchResponseAgentsItemToolsItemJsonSchema,
    AgentsSearchResponseAgentsItemToolsItemJsonSchemaItem,
    AgentsSearchResponseAgentsItemToolsItemLastUpdatedById,
    AgentsSearchResponseAgentsItemToolsItemLastUpdatedByIdItem,
    AgentsSearchResponseAgentsItemToolsItemName,
    AgentsSearchResponseAgentsItemToolsItemNameItem,
    AgentsSearchResponseAgentsItemToolsItemOrganizationId,
    AgentsSearchResponseAgentsItemToolsItemOrganizationIdItem,
    AgentsSearchResponseAgentsItemToolsItemSourceCode,
    AgentsSearchResponseAgentsItemToolsItemSourceCodeItem,
    AgentsSearchResponseAgentsItemToolsItemSourceType,
    AgentsSearchResponseAgentsItemToolsItemSourceTypeItem,
    AgentsSearchResponseAgentsItemToolsItemToolType,
    AgentsSearchResponseAgentsItemUpdatedAt,
    AgentsSearchResponseAgentsItemUpdatedAtItem,
    CreateAgentRequestToolRulesItem,
    UpdateAgentToolRulesItem,
)
from . import archival_memory, context, core_memory, memory_variables, messages, sources, templates, tools
from .memory_variables import MemoryVariablesListResponse
from .messages import LettaStreamingResponse, MessageUpdateContent
from .templates import TemplatesCreateResponse, TemplatesMigrateResponse

__all__ = [
    "AgentsSearchRequestSearchItem",
    "AgentsSearchRequestSearchItemField",
    "AgentsSearchRequestSearchItemOne",
    "AgentsSearchRequestSearchItemOneOperator",
    "AgentsSearchRequestSearchItemZero",
    "AgentsSearchResponse",
    "AgentsSearchResponseAgentsItem",
    "AgentsSearchResponseAgentsItemAgentType",
    "AgentsSearchResponseAgentsItemBaseTemplateId",
    "AgentsSearchResponseAgentsItemBaseTemplateIdItem",
    "AgentsSearchResponseAgentsItemCreatedAt",
    "AgentsSearchResponseAgentsItemCreatedAtItem",
    "AgentsSearchResponseAgentsItemCreatedById",
    "AgentsSearchResponseAgentsItemCreatedByIdItem",
    "AgentsSearchResponseAgentsItemDescription",
    "AgentsSearchResponseAgentsItemDescriptionItem",
    "AgentsSearchResponseAgentsItemEmbeddingConfig",
    "AgentsSearchResponseAgentsItemEmbeddingConfigAzureDeployment",
    "AgentsSearchResponseAgentsItemEmbeddingConfigAzureDeploymentItem",
    "AgentsSearchResponseAgentsItemEmbeddingConfigAzureEndpoint",
    "AgentsSearchResponseAgentsItemEmbeddingConfigAzureEndpointItem",
    "AgentsSearchResponseAgentsItemEmbeddingConfigAzureVersion",
    "AgentsSearchResponseAgentsItemEmbeddingConfigAzureVersionItem",
    "AgentsSearchResponseAgentsItemEmbeddingConfigEmbeddingChunkSize",
    "AgentsSearchResponseAgentsItemEmbeddingConfigEmbeddingChunkSizeItem",
    "AgentsSearchResponseAgentsItemEmbeddingConfigEmbeddingEndpoint",
    "AgentsSearchResponseAgentsItemEmbeddingConfigEmbeddingEndpointItem",
    "AgentsSearchResponseAgentsItemEmbeddingConfigEmbeddingEndpointType",
    "AgentsSearchResponseAgentsItemEmbeddingConfigHandle",
    "AgentsSearchResponseAgentsItemEmbeddingConfigHandleItem",
    "AgentsSearchResponseAgentsItemLastUpdatedById",
    "AgentsSearchResponseAgentsItemLastUpdatedByIdItem",
    "AgentsSearchResponseAgentsItemLlmConfig",
    "AgentsSearchResponseAgentsItemLlmConfigHandle",
    "AgentsSearchResponseAgentsItemLlmConfigHandleItem",
    "AgentsSearchResponseAgentsItemLlmConfigMaxTokens",
    "AgentsSearchResponseAgentsItemLlmConfigMaxTokensItem",
    "AgentsSearchResponseAgentsItemLlmConfigModelEndpoint",
    "AgentsSearchResponseAgentsItemLlmConfigModelEndpointItem",
    "AgentsSearchResponseAgentsItemLlmConfigModelEndpointType",
    "AgentsSearchResponseAgentsItemLlmConfigModelWrapper",
    "AgentsSearchResponseAgentsItemLlmConfigModelWrapperItem",
    "AgentsSearchResponseAgentsItemLlmConfigPutInnerThoughtsInKwargs",
    "AgentsSearchResponseAgentsItemLlmConfigPutInnerThoughtsInKwargsItem",
    "AgentsSearchResponseAgentsItemLlmConfigTemperature",
    "AgentsSearchResponseAgentsItemMemory",
    "AgentsSearchResponseAgentsItemMemoryBlocksItem",
    "AgentsSearchResponseAgentsItemMemoryBlocksItemCreatedById",
    "AgentsSearchResponseAgentsItemMemoryBlocksItemCreatedByIdItem",
    "AgentsSearchResponseAgentsItemMemoryBlocksItemDescription",
    "AgentsSearchResponseAgentsItemMemoryBlocksItemDescriptionItem",
    "AgentsSearchResponseAgentsItemMemoryBlocksItemId",
    "AgentsSearchResponseAgentsItemMemoryBlocksItemIsTemplate",
    "AgentsSearchResponseAgentsItemMemoryBlocksItemLabel",
    "AgentsSearchResponseAgentsItemMemoryBlocksItemLabelItem",
    "AgentsSearchResponseAgentsItemMemoryBlocksItemLastUpdatedById",
    "AgentsSearchResponseAgentsItemMemoryBlocksItemLastUpdatedByIdItem",
    "AgentsSearchResponseAgentsItemMemoryBlocksItemLimit",
    "AgentsSearchResponseAgentsItemMemoryBlocksItemMetadata",
    "AgentsSearchResponseAgentsItemMemoryBlocksItemMetadataItem",
    "AgentsSearchResponseAgentsItemMemoryBlocksItemName",
    "AgentsSearchResponseAgentsItemMemoryBlocksItemNameItem",
    "AgentsSearchResponseAgentsItemMemoryBlocksItemOrganizationId",
    "AgentsSearchResponseAgentsItemMemoryBlocksItemOrganizationIdItem",
    "AgentsSearchResponseAgentsItemMemoryPromptTemplate",
    "AgentsSearchResponseAgentsItemMessageIds",
    "AgentsSearchResponseAgentsItemMessageIdsItem",
    "AgentsSearchResponseAgentsItemMetadata",
    "AgentsSearchResponseAgentsItemMetadataItem",
    "AgentsSearchResponseAgentsItemOrganizationId",
    "AgentsSearchResponseAgentsItemOrganizationIdItem",
    "AgentsSearchResponseAgentsItemProjectId",
    "AgentsSearchResponseAgentsItemProjectIdItem",
    "AgentsSearchResponseAgentsItemSourcesItem",
    "AgentsSearchResponseAgentsItemSourcesItemCreatedAt",
    "AgentsSearchResponseAgentsItemSourcesItemCreatedAtItem",
    "AgentsSearchResponseAgentsItemSourcesItemCreatedById",
    "AgentsSearchResponseAgentsItemSourcesItemCreatedByIdItem",
    "AgentsSearchResponseAgentsItemSourcesItemDescription",
    "AgentsSearchResponseAgentsItemSourcesItemDescriptionItem",
    "AgentsSearchResponseAgentsItemSourcesItemEmbeddingConfig",
    "AgentsSearchResponseAgentsItemSourcesItemEmbeddingConfigAzureDeployment",
    "AgentsSearchResponseAgentsItemSourcesItemEmbeddingConfigAzureDeploymentItem",
    "AgentsSearchResponseAgentsItemSourcesItemEmbeddingConfigAzureEndpoint",
    "AgentsSearchResponseAgentsItemSourcesItemEmbeddingConfigAzureEndpointItem",
    "AgentsSearchResponseAgentsItemSourcesItemEmbeddingConfigAzureVersion",
    "AgentsSearchResponseAgentsItemSourcesItemEmbeddingConfigAzureVersionItem",
    "AgentsSearchResponseAgentsItemSourcesItemEmbeddingConfigEmbeddingChunkSize",
    "AgentsSearchResponseAgentsItemSourcesItemEmbeddingConfigEmbeddingChunkSizeItem",
    "AgentsSearchResponseAgentsItemSourcesItemEmbeddingConfigEmbeddingEndpoint",
    "AgentsSearchResponseAgentsItemSourcesItemEmbeddingConfigEmbeddingEndpointItem",
    "AgentsSearchResponseAgentsItemSourcesItemEmbeddingConfigEmbeddingEndpointType",
    "AgentsSearchResponseAgentsItemSourcesItemEmbeddingConfigHandle",
    "AgentsSearchResponseAgentsItemSourcesItemEmbeddingConfigHandleItem",
    "AgentsSearchResponseAgentsItemSourcesItemId",
    "AgentsSearchResponseAgentsItemSourcesItemLastUpdatedById",
    "AgentsSearchResponseAgentsItemSourcesItemLastUpdatedByIdItem",
    "AgentsSearchResponseAgentsItemSourcesItemMetadata",
    "AgentsSearchResponseAgentsItemSourcesItemMetadataItem",
    "AgentsSearchResponseAgentsItemSourcesItemOrganizationId",
    "AgentsSearchResponseAgentsItemSourcesItemOrganizationIdItem",
    "AgentsSearchResponseAgentsItemSourcesItemUpdatedAt",
    "AgentsSearchResponseAgentsItemSourcesItemUpdatedAtItem",
    "AgentsSearchResponseAgentsItemTemplateId",
    "AgentsSearchResponseAgentsItemTemplateIdItem",
    "AgentsSearchResponseAgentsItemToolExecEnvironmentVariables",
    "AgentsSearchResponseAgentsItemToolExecEnvironmentVariablesItem",
    "AgentsSearchResponseAgentsItemToolExecEnvironmentVariablesItemCreatedAt",
    "AgentsSearchResponseAgentsItemToolExecEnvironmentVariablesItemCreatedAtItem",
    "AgentsSearchResponseAgentsItemToolExecEnvironmentVariablesItemCreatedById",
    "AgentsSearchResponseAgentsItemToolExecEnvironmentVariablesItemCreatedByIdItem",
    "AgentsSearchResponseAgentsItemToolExecEnvironmentVariablesItemDescription",
    "AgentsSearchResponseAgentsItemToolExecEnvironmentVariablesItemDescriptionItem",
    "AgentsSearchResponseAgentsItemToolExecEnvironmentVariablesItemId",
    "AgentsSearchResponseAgentsItemToolExecEnvironmentVariablesItemLastUpdatedById",
    "AgentsSearchResponseAgentsItemToolExecEnvironmentVariablesItemLastUpdatedByIdItem",
    "AgentsSearchResponseAgentsItemToolExecEnvironmentVariablesItemOrganizationId",
    "AgentsSearchResponseAgentsItemToolExecEnvironmentVariablesItemOrganizationIdItem",
    "AgentsSearchResponseAgentsItemToolExecEnvironmentVariablesItemUpdatedAt",
    "AgentsSearchResponseAgentsItemToolExecEnvironmentVariablesItemUpdatedAtItem",
    "AgentsSearchResponseAgentsItemToolRules",
    "AgentsSearchResponseAgentsItemToolRulesItem",
    "AgentsSearchResponseAgentsItemToolRulesItemChildOutputMapping",
    "AgentsSearchResponseAgentsItemToolRulesItemChildOutputMappingDefaultChild",
    "AgentsSearchResponseAgentsItemToolRulesItemChildOutputMappingDefaultChildItem",
    "AgentsSearchResponseAgentsItemToolRulesItemChildOutputMappingRequireOutputMapping",
    "AgentsSearchResponseAgentsItemToolRulesItemChildOutputMappingType",
    "AgentsSearchResponseAgentsItemToolRulesItemChildren",
    "AgentsSearchResponseAgentsItemToolRulesItemChildrenType",
    "AgentsSearchResponseAgentsItemToolRulesItemItem",
    "AgentsSearchResponseAgentsItemToolRulesItemItemChildOutputMapping",
    "AgentsSearchResponseAgentsItemToolRulesItemItemChildOutputMappingDefaultChild",
    "AgentsSearchResponseAgentsItemToolRulesItemItemChildOutputMappingDefaultChildItem",
    "AgentsSearchResponseAgentsItemToolRulesItemItemChildOutputMappingRequireOutputMapping",
    "AgentsSearchResponseAgentsItemToolRulesItemItemChildOutputMappingType",
    "AgentsSearchResponseAgentsItemToolRulesItemItemChildren",
    "AgentsSearchResponseAgentsItemToolRulesItemItemChildrenType",
    "AgentsSearchResponseAgentsItemToolRulesItemItemOne",
    "AgentsSearchResponseAgentsItemToolRulesItemItemOneType",
    "AgentsSearchResponseAgentsItemToolRulesItemItemTwo",
    "AgentsSearchResponseAgentsItemToolRulesItemItemTwoType",
    "AgentsSearchResponseAgentsItemToolRulesItemOne",
    "AgentsSearchResponseAgentsItemToolRulesItemOneType",
    "AgentsSearchResponseAgentsItemToolRulesItemTwo",
    "AgentsSearchResponseAgentsItemToolRulesItemTwoType",
    "AgentsSearchResponseAgentsItemToolsItem",
    "AgentsSearchResponseAgentsItemToolsItemCreatedById",
    "AgentsSearchResponseAgentsItemToolsItemCreatedByIdItem",
    "AgentsSearchResponseAgentsItemToolsItemDescription",
    "AgentsSearchResponseAgentsItemToolsItemDescriptionItem",
    "AgentsSearchResponseAgentsItemToolsItemJsonSchema",
    "AgentsSearchResponseAgentsItemToolsItemJsonSchemaItem",
    "AgentsSearchResponseAgentsItemToolsItemLastUpdatedById",
    "AgentsSearchResponseAgentsItemToolsItemLastUpdatedByIdItem",
    "AgentsSearchResponseAgentsItemToolsItemName",
    "AgentsSearchResponseAgentsItemToolsItemNameItem",
    "AgentsSearchResponseAgentsItemToolsItemOrganizationId",
    "AgentsSearchResponseAgentsItemToolsItemOrganizationIdItem",
    "AgentsSearchResponseAgentsItemToolsItemSourceCode",
    "AgentsSearchResponseAgentsItemToolsItemSourceCodeItem",
    "AgentsSearchResponseAgentsItemToolsItemSourceType",
    "AgentsSearchResponseAgentsItemToolsItemSourceTypeItem",
    "AgentsSearchResponseAgentsItemToolsItemToolType",
    "AgentsSearchResponseAgentsItemUpdatedAt",
    "AgentsSearchResponseAgentsItemUpdatedAtItem",
    "CreateAgentRequestToolRulesItem",
    "LettaStreamingResponse",
    "MemoryVariablesListResponse",
    "MessageUpdateContent",
    "TemplatesCreateResponse",
    "TemplatesMigrateResponse",
    "UpdateAgentToolRulesItem",
    "archival_memory",
    "context",
    "core_memory",
    "memory_variables",
    "messages",
    "sources",
    "templates",
    "tools",
]
