# This file was auto-generated by Fern from our API Definition.

import typing
from .templates_create_agents_from_template_response_agents_item_tool_exec_environment_variables_item import (
    TemplatesCreateAgentsFromTemplateResponseAgentsItemToolExecEnvironmentVariablesItem,
)

TemplatesCreateAgentsFromTemplateResponseAgentsItemToolExecEnvironmentVariables = typing.Union[
    typing.List[TemplatesCreateAgentsFromTemplateResponseAgentsItemToolExecEnvironmentVariablesItem],
    typing.Optional[typing.Any],
]
