# This file was auto-generated by Fern from our API Definition.

from .types import (
    TemplatesCreateAgentsFromTemplateResponse,
    TemplatesCreateAgentsFromTemplateResponseAgentsItem,
    TemplatesCreateAgentsFromTemplateResponseAgentsItemAgentType,
    TemplatesCreateAgentsFromTemplateResponseAgentsItemBaseTemplateId,
    TemplatesCreateAgentsFromTemplateResponseAgentsItemBaseTemplateIdItem,
    TemplatesCreateAgentsFromTemplateResponseAgentsItemCreatedAt,
    TemplatesCreateAgentsFromTemplateResponseAgentsItemCreatedAtItem,
    TemplatesCreateAgentsFromTemplateResponseAgentsItemCreatedById,
    TemplatesCreateAgentsFromTemplateResponseAgentsItemCreatedByIdItem,
    TemplatesCreateAgentsFromTemplateResponseAgentsItemDescription,
    TemplatesCreateAgentsFromTemplateResponseAgentsItemDescriptionItem,
    TemplatesCreateAgentsFromTemplateResponseAgentsItemEmbeddingConfig,
    TemplatesCreateAgentsFromTemplateResponseAgentsItemEmbeddingConfigAzureDeployment,
    TemplatesCreateAgentsFromTemplateResponseAgentsItemEmbeddingConfigAzureDeploymentItem,
    TemplatesCreateAgentsFromTemplateResponseAgentsItemEmbeddingConfigAzureEndpoint,
    TemplatesCreateAgentsFromTemplateResponseAgentsItemEmbeddingConfigAzureEndpointItem,
    TemplatesCreateAgentsFromTemplateResponseAgentsItemEmbeddingConfigAzureVersion,
    TemplatesCreateAgentsFromTemplateResponseAgentsItemEmbeddingConfigAzureVersionItem,
    TemplatesCreateAgentsFromTemplateResponseAgentsItemEmbeddingConfigEmbeddingChunkSize,
    TemplatesCreateAgentsFromTemplateResponseAgentsItemEmbeddingConfigEmbeddingChunkSizeItem,
    TemplatesCreateAgentsFromTemplateResponseAgentsItemEmbeddingConfigEmbeddingEndpoint,
    TemplatesCreateAgentsFromTemplateResponseAgentsItemEmbeddingConfigEmbeddingEndpointItem,
    TemplatesCreateAgentsFromTemplateResponseAgentsItemEmbeddingConfigEmbeddingEndpointType,
    TemplatesCreateAgentsFromTemplateResponseAgentsItemEmbeddingConfigHandle,
    TemplatesCreateAgentsFromTemplateResponseAgentsItemEmbeddingConfigHandleItem,
    TemplatesCreateAgentsFromTemplateResponseAgentsItemLastUpdatedById,
    TemplatesCreateAgentsFromTemplateResponseAgentsItemLastUpdatedByIdItem,
    TemplatesCreateAgentsFromTemplateResponseAgentsItemLlmConfig,
    TemplatesCreateAgentsFromTemplateResponseAgentsItemLlmConfigHandle,
    TemplatesCreateAgentsFromTemplateResponseAgentsItemLlmConfigHandleItem,
    TemplatesCreateAgentsFromTemplateResponseAgentsItemLlmConfigMaxTokens,
    TemplatesCreateAgentsFromTemplateResponseAgentsItemLlmConfigMaxTokensItem,
    TemplatesCreateAgentsFromTemplateResponseAgentsItemLlmConfigModelEndpoint,
    TemplatesCreateAgentsFromTemplateResponseAgentsItemLlmConfigModelEndpointItem,
    TemplatesCreateAgentsFromTemplateResponseAgentsItemLlmConfigModelEndpointType,
    TemplatesCreateAgentsFromTemplateResponseAgentsItemLlmConfigModelWrapper,
    TemplatesCreateAgentsFromTemplateResponseAgentsItemLlmConfigModelWrapperItem,
    TemplatesCreateAgentsFromTemplateResponseAgentsItemLlmConfigPutInnerThoughtsInKwargs,
    TemplatesCreateAgentsFromTemplateResponseAgentsItemLlmConfigPutInnerThoughtsInKwargsItem,
    TemplatesCreateAgentsFromTemplateResponseAgentsItemLlmConfigTemperature,
    TemplatesCreateAgentsFromTemplateResponseAgentsItemMemory,
    TemplatesCreateAgentsFromTemplateResponseAgentsItemMemoryBlocksItem,
    TemplatesCreateAgentsFromTemplateResponseAgentsItemMemoryBlocksItemCreatedById,
    TemplatesCreateAgentsFromTemplateResponseAgentsItemMemoryBlocksItemCreatedByIdItem,
    TemplatesCreateAgentsFromTemplateResponseAgentsItemMemoryBlocksItemDescription,
    TemplatesCreateAgentsFromTemplateResponseAgentsItemMemoryBlocksItemDescriptionItem,
    TemplatesCreateAgentsFromTemplateResponseAgentsItemMemoryBlocksItemId,
    TemplatesCreateAgentsFromTemplateResponseAgentsItemMemoryBlocksItemIsTemplate,
    TemplatesCreateAgentsFromTemplateResponseAgentsItemMemoryBlocksItemLabel,
    TemplatesCreateAgentsFromTemplateResponseAgentsItemMemoryBlocksItemLabelItem,
    TemplatesCreateAgentsFromTemplateResponseAgentsItemMemoryBlocksItemLastUpdatedById,
    TemplatesCreateAgentsFromTemplateResponseAgentsItemMemoryBlocksItemLastUpdatedByIdItem,
    TemplatesCreateAgentsFromTemplateResponseAgentsItemMemoryBlocksItemLimit,
    TemplatesCreateAgentsFromTemplateResponseAgentsItemMemoryBlocksItemMetadata,
    TemplatesCreateAgentsFromTemplateResponseAgentsItemMemoryBlocksItemMetadataItem,
    TemplatesCreateAgentsFromTemplateResponseAgentsItemMemoryBlocksItemName,
    TemplatesCreateAgentsFromTemplateResponseAgentsItemMemoryBlocksItemNameItem,
    TemplatesCreateAgentsFromTemplateResponseAgentsItemMemoryBlocksItemOrganizationId,
    TemplatesCreateAgentsFromTemplateResponseAgentsItemMemoryBlocksItemOrganizationIdItem,
    TemplatesCreateAgentsFromTemplateResponseAgentsItemMemoryPromptTemplate,
    TemplatesCreateAgentsFromTemplateResponseAgentsItemMessageIds,
    TemplatesCreateAgentsFromTemplateResponseAgentsItemMessageIdsItem,
    TemplatesCreateAgentsFromTemplateResponseAgentsItemMetadata,
    TemplatesCreateAgentsFromTemplateResponseAgentsItemMetadataItem,
    TemplatesCreateAgentsFromTemplateResponseAgentsItemOrganizationId,
    TemplatesCreateAgentsFromTemplateResponseAgentsItemOrganizationIdItem,
    TemplatesCreateAgentsFromTemplateResponseAgentsItemProjectId,
    TemplatesCreateAgentsFromTemplateResponseAgentsItemProjectIdItem,
    TemplatesCreateAgentsFromTemplateResponseAgentsItemSourcesItem,
    TemplatesCreateAgentsFromTemplateResponseAgentsItemSourcesItemCreatedAt,
    TemplatesCreateAgentsFromTemplateResponseAgentsItemSourcesItemCreatedAtItem,
    TemplatesCreateAgentsFromTemplateResponseAgentsItemSourcesItemCreatedById,
    TemplatesCreateAgentsFromTemplateResponseAgentsItemSourcesItemCreatedByIdItem,
    TemplatesCreateAgentsFromTemplateResponseAgentsItemSourcesItemDescription,
    TemplatesCreateAgentsFromTemplateResponseAgentsItemSourcesItemDescriptionItem,
    TemplatesCreateAgentsFromTemplateResponseAgentsItemSourcesItemEmbeddingConfig,
    TemplatesCreateAgentsFromTemplateResponseAgentsItemSourcesItemEmbeddingConfigAzureDeployment,
    TemplatesCreateAgentsFromTemplateResponseAgentsItemSourcesItemEmbeddingConfigAzureDeploymentItem,
    TemplatesCreateAgentsFromTemplateResponseAgentsItemSourcesItemEmbeddingConfigAzureEndpoint,
    TemplatesCreateAgentsFromTemplateResponseAgentsItemSourcesItemEmbeddingConfigAzureEndpointItem,
    TemplatesCreateAgentsFromTemplateResponseAgentsItemSourcesItemEmbeddingConfigAzureVersion,
    TemplatesCreateAgentsFromTemplateResponseAgentsItemSourcesItemEmbeddingConfigAzureVersionItem,
    TemplatesCreateAgentsFromTemplateResponseAgentsItemSourcesItemEmbeddingConfigEmbeddingChunkSize,
    TemplatesCreateAgentsFromTemplateResponseAgentsItemSourcesItemEmbeddingConfigEmbeddingChunkSizeItem,
    TemplatesCreateAgentsFromTemplateResponseAgentsItemSourcesItemEmbeddingConfigEmbeddingEndpoint,
    TemplatesCreateAgentsFromTemplateResponseAgentsItemSourcesItemEmbeddingConfigEmbeddingEndpointItem,
    TemplatesCreateAgentsFromTemplateResponseAgentsItemSourcesItemEmbeddingConfigEmbeddingEndpointType,
    TemplatesCreateAgentsFromTemplateResponseAgentsItemSourcesItemEmbeddingConfigHandle,
    TemplatesCreateAgentsFromTemplateResponseAgentsItemSourcesItemEmbeddingConfigHandleItem,
    TemplatesCreateAgentsFromTemplateResponseAgentsItemSourcesItemId,
    TemplatesCreateAgentsFromTemplateResponseAgentsItemSourcesItemLastUpdatedById,
    TemplatesCreateAgentsFromTemplateResponseAgentsItemSourcesItemLastUpdatedByIdItem,
    TemplatesCreateAgentsFromTemplateResponseAgentsItemSourcesItemMetadata,
    TemplatesCreateAgentsFromTemplateResponseAgentsItemSourcesItemMetadataItem,
    TemplatesCreateAgentsFromTemplateResponseAgentsItemSourcesItemOrganizationId,
    TemplatesCreateAgentsFromTemplateResponseAgentsItemSourcesItemOrganizationIdItem,
    TemplatesCreateAgentsFromTemplateResponseAgentsItemSourcesItemUpdatedAt,
    TemplatesCreateAgentsFromTemplateResponseAgentsItemSourcesItemUpdatedAtItem,
    TemplatesCreateAgentsFromTemplateResponseAgentsItemTemplateId,
    TemplatesCreateAgentsFromTemplateResponseAgentsItemTemplateIdItem,
    TemplatesCreateAgentsFromTemplateResponseAgentsItemToolExecEnvironmentVariables,
    TemplatesCreateAgentsFromTemplateResponseAgentsItemToolExecEnvironmentVariablesItem,
    TemplatesCreateAgentsFromTemplateResponseAgentsItemToolExecEnvironmentVariablesItemCreatedAt,
    TemplatesCreateAgentsFromTemplateResponseAgentsItemToolExecEnvironmentVariablesItemCreatedAtItem,
    TemplatesCreateAgentsFromTemplateResponseAgentsItemToolExecEnvironmentVariablesItemCreatedById,
    TemplatesCreateAgentsFromTemplateResponseAgentsItemToolExecEnvironmentVariablesItemCreatedByIdItem,
    TemplatesCreateAgentsFromTemplateResponseAgentsItemToolExecEnvironmentVariablesItemDescription,
    TemplatesCreateAgentsFromTemplateResponseAgentsItemToolExecEnvironmentVariablesItemDescriptionItem,
    TemplatesCreateAgentsFromTemplateResponseAgentsItemToolExecEnvironmentVariablesItemId,
    TemplatesCreateAgentsFromTemplateResponseAgentsItemToolExecEnvironmentVariablesItemLastUpdatedById,
    TemplatesCreateAgentsFromTemplateResponseAgentsItemToolExecEnvironmentVariablesItemLastUpdatedByIdItem,
    TemplatesCreateAgentsFromTemplateResponseAgentsItemToolExecEnvironmentVariablesItemOrganizationId,
    TemplatesCreateAgentsFromTemplateResponseAgentsItemToolExecEnvironmentVariablesItemOrganizationIdItem,
    TemplatesCreateAgentsFromTemplateResponseAgentsItemToolExecEnvironmentVariablesItemUpdatedAt,
    TemplatesCreateAgentsFromTemplateResponseAgentsItemToolExecEnvironmentVariablesItemUpdatedAtItem,
    TemplatesCreateAgentsFromTemplateResponseAgentsItemToolRules,
    TemplatesCreateAgentsFromTemplateResponseAgentsItemToolRulesItem,
    TemplatesCreateAgentsFromTemplateResponseAgentsItemToolRulesItemChildOutputMapping,
    TemplatesCreateAgentsFromTemplateResponseAgentsItemToolRulesItemChildOutputMappingDefaultChild,
    TemplatesCreateAgentsFromTemplateResponseAgentsItemToolRulesItemChildOutputMappingDefaultChildItem,
    TemplatesCreateAgentsFromTemplateResponseAgentsItemToolRulesItemChildOutputMappingRequireOutputMapping,
    TemplatesCreateAgentsFromTemplateResponseAgentsItemToolRulesItemChildOutputMappingType,
    TemplatesCreateAgentsFromTemplateResponseAgentsItemToolRulesItemChildren,
    TemplatesCreateAgentsFromTemplateResponseAgentsItemToolRulesItemChildrenType,
    TemplatesCreateAgentsFromTemplateResponseAgentsItemToolRulesItemItem,
    TemplatesCreateAgentsFromTemplateResponseAgentsItemToolRulesItemItemChildOutputMapping,
    TemplatesCreateAgentsFromTemplateResponseAgentsItemToolRulesItemItemChildOutputMappingDefaultChild,
    TemplatesCreateAgentsFromTemplateResponseAgentsItemToolRulesItemItemChildOutputMappingDefaultChildItem,
    TemplatesCreateAgentsFromTemplateResponseAgentsItemToolRulesItemItemChildOutputMappingRequireOutputMapping,
    TemplatesCreateAgentsFromTemplateResponseAgentsItemToolRulesItemItemChildOutputMappingType,
    TemplatesCreateAgentsFromTemplateResponseAgentsItemToolRulesItemItemChildren,
    TemplatesCreateAgentsFromTemplateResponseAgentsItemToolRulesItemItemChildrenType,
    TemplatesCreateAgentsFromTemplateResponseAgentsItemToolRulesItemItemOne,
    TemplatesCreateAgentsFromTemplateResponseAgentsItemToolRulesItemItemOneType,
    TemplatesCreateAgentsFromTemplateResponseAgentsItemToolRulesItemItemTwo,
    TemplatesCreateAgentsFromTemplateResponseAgentsItemToolRulesItemItemTwoType,
    TemplatesCreateAgentsFromTemplateResponseAgentsItemToolRulesItemOne,
    TemplatesCreateAgentsFromTemplateResponseAgentsItemToolRulesItemOneType,
    TemplatesCreateAgentsFromTemplateResponseAgentsItemToolRulesItemTwo,
    TemplatesCreateAgentsFromTemplateResponseAgentsItemToolRulesItemTwoType,
    TemplatesCreateAgentsFromTemplateResponseAgentsItemToolsItem,
    TemplatesCreateAgentsFromTemplateResponseAgentsItemToolsItemCreatedById,
    TemplatesCreateAgentsFromTemplateResponseAgentsItemToolsItemCreatedByIdItem,
    TemplatesCreateAgentsFromTemplateResponseAgentsItemToolsItemDescription,
    TemplatesCreateAgentsFromTemplateResponseAgentsItemToolsItemDescriptionItem,
    TemplatesCreateAgentsFromTemplateResponseAgentsItemToolsItemJsonSchema,
    TemplatesCreateAgentsFromTemplateResponseAgentsItemToolsItemJsonSchemaItem,
    TemplatesCreateAgentsFromTemplateResponseAgentsItemToolsItemLastUpdatedById,
    TemplatesCreateAgentsFromTemplateResponseAgentsItemToolsItemLastUpdatedByIdItem,
    TemplatesCreateAgentsFromTemplateResponseAgentsItemToolsItemName,
    TemplatesCreateAgentsFromTemplateResponseAgentsItemToolsItemNameItem,
    TemplatesCreateAgentsFromTemplateResponseAgentsItemToolsItemOrganizationId,
    TemplatesCreateAgentsFromTemplateResponseAgentsItemToolsItemOrganizationIdItem,
    TemplatesCreateAgentsFromTemplateResponseAgentsItemToolsItemSourceCode,
    TemplatesCreateAgentsFromTemplateResponseAgentsItemToolsItemSourceCodeItem,
    TemplatesCreateAgentsFromTemplateResponseAgentsItemToolsItemSourceType,
    TemplatesCreateAgentsFromTemplateResponseAgentsItemToolsItemSourceTypeItem,
    TemplatesCreateAgentsFromTemplateResponseAgentsItemToolsItemToolType,
    TemplatesCreateAgentsFromTemplateResponseAgentsItemUpdatedAt,
    TemplatesCreateAgentsFromTemplateResponseAgentsItemUpdatedAtItem,
)

__all__ = [
    "TemplatesCreateAgentsFromTemplateResponse",
    "TemplatesCreateAgentsFromTemplateResponseAgentsItem",
    "TemplatesCreateAgentsFromTemplateResponseAgentsItemAgentType",
    "TemplatesCreateAgentsFromTemplateResponseAgentsItemBaseTemplateId",
    "TemplatesCreateAgentsFromTemplateResponseAgentsItemBaseTemplateIdItem",
    "TemplatesCreateAgentsFromTemplateResponseAgentsItemCreatedAt",
    "TemplatesCreateAgentsFromTemplateResponseAgentsItemCreatedAtItem",
    "TemplatesCreateAgentsFromTemplateResponseAgentsItemCreatedById",
    "TemplatesCreateAgentsFromTemplateResponseAgentsItemCreatedByIdItem",
    "TemplatesCreateAgentsFromTemplateResponseAgentsItemDescription",
    "TemplatesCreateAgentsFromTemplateResponseAgentsItemDescriptionItem",
    "TemplatesCreateAgentsFromTemplateResponseAgentsItemEmbeddingConfig",
    "TemplatesCreateAgentsFromTemplateResponseAgentsItemEmbeddingConfigAzureDeployment",
    "TemplatesCreateAgentsFromTemplateResponseAgentsItemEmbeddingConfigAzureDeploymentItem",
    "TemplatesCreateAgentsFromTemplateResponseAgentsItemEmbeddingConfigAzureEndpoint",
    "TemplatesCreateAgentsFromTemplateResponseAgentsItemEmbeddingConfigAzureEndpointItem",
    "TemplatesCreateAgentsFromTemplateResponseAgentsItemEmbeddingConfigAzureVersion",
    "TemplatesCreateAgentsFromTemplateResponseAgentsItemEmbeddingConfigAzureVersionItem",
    "TemplatesCreateAgentsFromTemplateResponseAgentsItemEmbeddingConfigEmbeddingChunkSize",
    "TemplatesCreateAgentsFromTemplateResponseAgentsItemEmbeddingConfigEmbeddingChunkSizeItem",
    "TemplatesCreateAgentsFromTemplateResponseAgentsItemEmbeddingConfigEmbeddingEndpoint",
    "TemplatesCreateAgentsFromTemplateResponseAgentsItemEmbeddingConfigEmbeddingEndpointItem",
    "TemplatesCreateAgentsFromTemplateResponseAgentsItemEmbeddingConfigEmbeddingEndpointType",
    "TemplatesCreateAgentsFromTemplateResponseAgentsItemEmbeddingConfigHandle",
    "TemplatesCreateAgentsFromTemplateResponseAgentsItemEmbeddingConfigHandleItem",
    "TemplatesCreateAgentsFromTemplateResponseAgentsItemLastUpdatedById",
    "TemplatesCreateAgentsFromTemplateResponseAgentsItemLastUpdatedByIdItem",
    "TemplatesCreateAgentsFromTemplateResponseAgentsItemLlmConfig",
    "TemplatesCreateAgentsFromTemplateResponseAgentsItemLlmConfigHandle",
    "TemplatesCreateAgentsFromTemplateResponseAgentsItemLlmConfigHandleItem",
    "TemplatesCreateAgentsFromTemplateResponseAgentsItemLlmConfigMaxTokens",
    "TemplatesCreateAgentsFromTemplateResponseAgentsItemLlmConfigMaxTokensItem",
    "TemplatesCreateAgentsFromTemplateResponseAgentsItemLlmConfigModelEndpoint",
    "TemplatesCreateAgentsFromTemplateResponseAgentsItemLlmConfigModelEndpointItem",
    "TemplatesCreateAgentsFromTemplateResponseAgentsItemLlmConfigModelEndpointType",
    "TemplatesCreateAgentsFromTemplateResponseAgentsItemLlmConfigModelWrapper",
    "TemplatesCreateAgentsFromTemplateResponseAgentsItemLlmConfigModelWrapperItem",
    "TemplatesCreateAgentsFromTemplateResponseAgentsItemLlmConfigPutInnerThoughtsInKwargs",
    "TemplatesCreateAgentsFromTemplateResponseAgentsItemLlmConfigPutInnerThoughtsInKwargsItem",
    "TemplatesCreateAgentsFromTemplateResponseAgentsItemLlmConfigTemperature",
    "TemplatesCreateAgentsFromTemplateResponseAgentsItemMemory",
    "TemplatesCreateAgentsFromTemplateResponseAgentsItemMemoryBlocksItem",
    "TemplatesCreateAgentsFromTemplateResponseAgentsItemMemoryBlocksItemCreatedById",
    "TemplatesCreateAgentsFromTemplateResponseAgentsItemMemoryBlocksItemCreatedByIdItem",
    "TemplatesCreateAgentsFromTemplateResponseAgentsItemMemoryBlocksItemDescription",
    "TemplatesCreateAgentsFromTemplateResponseAgentsItemMemoryBlocksItemDescriptionItem",
    "TemplatesCreateAgentsFromTemplateResponseAgentsItemMemoryBlocksItemId",
    "TemplatesCreateAgentsFromTemplateResponseAgentsItemMemoryBlocksItemIsTemplate",
    "TemplatesCreateAgentsFromTemplateResponseAgentsItemMemoryBlocksItemLabel",
    "TemplatesCreateAgentsFromTemplateResponseAgentsItemMemoryBlocksItemLabelItem",
    "TemplatesCreateAgentsFromTemplateResponseAgentsItemMemoryBlocksItemLastUpdatedById",
    "TemplatesCreateAgentsFromTemplateResponseAgentsItemMemoryBlocksItemLastUpdatedByIdItem",
    "TemplatesCreateAgentsFromTemplateResponseAgentsItemMemoryBlocksItemLimit",
    "TemplatesCreateAgentsFromTemplateResponseAgentsItemMemoryBlocksItemMetadata",
    "TemplatesCreateAgentsFromTemplateResponseAgentsItemMemoryBlocksItemMetadataItem",
    "TemplatesCreateAgentsFromTemplateResponseAgentsItemMemoryBlocksItemName",
    "TemplatesCreateAgentsFromTemplateResponseAgentsItemMemoryBlocksItemNameItem",
    "TemplatesCreateAgentsFromTemplateResponseAgentsItemMemoryBlocksItemOrganizationId",
    "TemplatesCreateAgentsFromTemplateResponseAgentsItemMemoryBlocksItemOrganizationIdItem",
    "TemplatesCreateAgentsFromTemplateResponseAgentsItemMemoryPromptTemplate",
    "TemplatesCreateAgentsFromTemplateResponseAgentsItemMessageIds",
    "TemplatesCreateAgentsFromTemplateResponseAgentsItemMessageIdsItem",
    "TemplatesCreateAgentsFromTemplateResponseAgentsItemMetadata",
    "TemplatesCreateAgentsFromTemplateResponseAgentsItemMetadataItem",
    "TemplatesCreateAgentsFromTemplateResponseAgentsItemOrganizationId",
    "TemplatesCreateAgentsFromTemplateResponseAgentsItemOrganizationIdItem",
    "TemplatesCreateAgentsFromTemplateResponseAgentsItemProjectId",
    "TemplatesCreateAgentsFromTemplateResponseAgentsItemProjectIdItem",
    "TemplatesCreateAgentsFromTemplateResponseAgentsItemSourcesItem",
    "TemplatesCreateAgentsFromTemplateResponseAgentsItemSourcesItemCreatedAt",
    "TemplatesCreateAgentsFromTemplateResponseAgentsItemSourcesItemCreatedAtItem",
    "TemplatesCreateAgentsFromTemplateResponseAgentsItemSourcesItemCreatedById",
    "TemplatesCreateAgentsFromTemplateResponseAgentsItemSourcesItemCreatedByIdItem",
    "TemplatesCreateAgentsFromTemplateResponseAgentsItemSourcesItemDescription",
    "TemplatesCreateAgentsFromTemplateResponseAgentsItemSourcesItemDescriptionItem",
    "TemplatesCreateAgentsFromTemplateResponseAgentsItemSourcesItemEmbeddingConfig",
    "TemplatesCreateAgentsFromTemplateResponseAgentsItemSourcesItemEmbeddingConfigAzureDeployment",
    "TemplatesCreateAgentsFromTemplateResponseAgentsItemSourcesItemEmbeddingConfigAzureDeploymentItem",
    "TemplatesCreateAgentsFromTemplateResponseAgentsItemSourcesItemEmbeddingConfigAzureEndpoint",
    "TemplatesCreateAgentsFromTemplateResponseAgentsItemSourcesItemEmbeddingConfigAzureEndpointItem",
    "TemplatesCreateAgentsFromTemplateResponseAgentsItemSourcesItemEmbeddingConfigAzureVersion",
    "TemplatesCreateAgentsFromTemplateResponseAgentsItemSourcesItemEmbeddingConfigAzureVersionItem",
    "TemplatesCreateAgentsFromTemplateResponseAgentsItemSourcesItemEmbeddingConfigEmbeddingChunkSize",
    "TemplatesCreateAgentsFromTemplateResponseAgentsItemSourcesItemEmbeddingConfigEmbeddingChunkSizeItem",
    "TemplatesCreateAgentsFromTemplateResponseAgentsItemSourcesItemEmbeddingConfigEmbeddingEndpoint",
    "TemplatesCreateAgentsFromTemplateResponseAgentsItemSourcesItemEmbeddingConfigEmbeddingEndpointItem",
    "TemplatesCreateAgentsFromTemplateResponseAgentsItemSourcesItemEmbeddingConfigEmbeddingEndpointType",
    "TemplatesCreateAgentsFromTemplateResponseAgentsItemSourcesItemEmbeddingConfigHandle",
    "TemplatesCreateAgentsFromTemplateResponseAgentsItemSourcesItemEmbeddingConfigHandleItem",
    "TemplatesCreateAgentsFromTemplateResponseAgentsItemSourcesItemId",
    "TemplatesCreateAgentsFromTemplateResponseAgentsItemSourcesItemLastUpdatedById",
    "TemplatesCreateAgentsFromTemplateResponseAgentsItemSourcesItemLastUpdatedByIdItem",
    "TemplatesCreateAgentsFromTemplateResponseAgentsItemSourcesItemMetadata",
    "TemplatesCreateAgentsFromTemplateResponseAgentsItemSourcesItemMetadataItem",
    "TemplatesCreateAgentsFromTemplateResponseAgentsItemSourcesItemOrganizationId",
    "TemplatesCreateAgentsFromTemplateResponseAgentsItemSourcesItemOrganizationIdItem",
    "TemplatesCreateAgentsFromTemplateResponseAgentsItemSourcesItemUpdatedAt",
    "TemplatesCreateAgentsFromTemplateResponseAgentsItemSourcesItemUpdatedAtItem",
    "TemplatesCreateAgentsFromTemplateResponseAgentsItemTemplateId",
    "TemplatesCreateAgentsFromTemplateResponseAgentsItemTemplateIdItem",
    "TemplatesCreateAgentsFromTemplateResponseAgentsItemToolExecEnvironmentVariables",
    "TemplatesCreateAgentsFromTemplateResponseAgentsItemToolExecEnvironmentVariablesItem",
    "TemplatesCreateAgentsFromTemplateResponseAgentsItemToolExecEnvironmentVariablesItemCreatedAt",
    "TemplatesCreateAgentsFromTemplateResponseAgentsItemToolExecEnvironmentVariablesItemCreatedAtItem",
    "TemplatesCreateAgentsFromTemplateResponseAgentsItemToolExecEnvironmentVariablesItemCreatedById",
    "TemplatesCreateAgentsFromTemplateResponseAgentsItemToolExecEnvironmentVariablesItemCreatedByIdItem",
    "TemplatesCreateAgentsFromTemplateResponseAgentsItemToolExecEnvironmentVariablesItemDescription",
    "TemplatesCreateAgentsFromTemplateResponseAgentsItemToolExecEnvironmentVariablesItemDescriptionItem",
    "TemplatesCreateAgentsFromTemplateResponseAgentsItemToolExecEnvironmentVariablesItemId",
    "TemplatesCreateAgentsFromTemplateResponseAgentsItemToolExecEnvironmentVariablesItemLastUpdatedById",
    "TemplatesCreateAgentsFromTemplateResponseAgentsItemToolExecEnvironmentVariablesItemLastUpdatedByIdItem",
    "TemplatesCreateAgentsFromTemplateResponseAgentsItemToolExecEnvironmentVariablesItemOrganizationId",
    "TemplatesCreateAgentsFromTemplateResponseAgentsItemToolExecEnvironmentVariablesItemOrganizationIdItem",
    "TemplatesCreateAgentsFromTemplateResponseAgentsItemToolExecEnvironmentVariablesItemUpdatedAt",
    "TemplatesCreateAgentsFromTemplateResponseAgentsItemToolExecEnvironmentVariablesItemUpdatedAtItem",
    "TemplatesCreateAgentsFromTemplateResponseAgentsItemToolRules",
    "TemplatesCreateAgentsFromTemplateResponseAgentsItemToolRulesItem",
    "TemplatesCreateAgentsFromTemplateResponseAgentsItemToolRulesItemChildOutputMapping",
    "TemplatesCreateAgentsFromTemplateResponseAgentsItemToolRulesItemChildOutputMappingDefaultChild",
    "TemplatesCreateAgentsFromTemplateResponseAgentsItemToolRulesItemChildOutputMappingDefaultChildItem",
    "TemplatesCreateAgentsFromTemplateResponseAgentsItemToolRulesItemChildOutputMappingRequireOutputMapping",
    "TemplatesCreateAgentsFromTemplateResponseAgentsItemToolRulesItemChildOutputMappingType",
    "TemplatesCreateAgentsFromTemplateResponseAgentsItemToolRulesItemChildren",
    "TemplatesCreateAgentsFromTemplateResponseAgentsItemToolRulesItemChildrenType",
    "TemplatesCreateAgentsFromTemplateResponseAgentsItemToolRulesItemItem",
    "TemplatesCreateAgentsFromTemplateResponseAgentsItemToolRulesItemItemChildOutputMapping",
    "TemplatesCreateAgentsFromTemplateResponseAgentsItemToolRulesItemItemChildOutputMappingDefaultChild",
    "TemplatesCreateAgentsFromTemplateResponseAgentsItemToolRulesItemItemChildOutputMappingDefaultChildItem",
    "TemplatesCreateAgentsFromTemplateResponseAgentsItemToolRulesItemItemChildOutputMappingRequireOutputMapping",
    "TemplatesCreateAgentsFromTemplateResponseAgentsItemToolRulesItemItemChildOutputMappingType",
    "TemplatesCreateAgentsFromTemplateResponseAgentsItemToolRulesItemItemChildren",
    "TemplatesCreateAgentsFromTemplateResponseAgentsItemToolRulesItemItemChildrenType",
    "TemplatesCreateAgentsFromTemplateResponseAgentsItemToolRulesItemItemOne",
    "TemplatesCreateAgentsFromTemplateResponseAgentsItemToolRulesItemItemOneType",
    "TemplatesCreateAgentsFromTemplateResponseAgentsItemToolRulesItemItemTwo",
    "TemplatesCreateAgentsFromTemplateResponseAgentsItemToolRulesItemItemTwoType",
    "TemplatesCreateAgentsFromTemplateResponseAgentsItemToolRulesItemOne",
    "TemplatesCreateAgentsFromTemplateResponseAgentsItemToolRulesItemOneType",
    "TemplatesCreateAgentsFromTemplateResponseAgentsItemToolRulesItemTwo",
    "TemplatesCreateAgentsFromTemplateResponseAgentsItemToolRulesItemTwoType",
    "TemplatesCreateAgentsFromTemplateResponseAgentsItemToolsItem",
    "TemplatesCreateAgentsFromTemplateResponseAgentsItemToolsItemCreatedById",
    "TemplatesCreateAgentsFromTemplateResponseAgentsItemToolsItemCreatedByIdItem",
    "TemplatesCreateAgentsFromTemplateResponseAgentsItemToolsItemDescription",
    "TemplatesCreateAgentsFromTemplateResponseAgentsItemToolsItemDescriptionItem",
    "TemplatesCreateAgentsFromTemplateResponseAgentsItemToolsItemJsonSchema",
    "TemplatesCreateAgentsFromTemplateResponseAgentsItemToolsItemJsonSchemaItem",
    "TemplatesCreateAgentsFromTemplateResponseAgentsItemToolsItemLastUpdatedById",
    "TemplatesCreateAgentsFromTemplateResponseAgentsItemToolsItemLastUpdatedByIdItem",
    "TemplatesCreateAgentsFromTemplateResponseAgentsItemToolsItemName",
    "TemplatesCreateAgentsFromTemplateResponseAgentsItemToolsItemNameItem",
    "TemplatesCreateAgentsFromTemplateResponseAgentsItemToolsItemOrganizationId",
    "TemplatesCreateAgentsFromTemplateResponseAgentsItemToolsItemOrganizationIdItem",
    "TemplatesCreateAgentsFromTemplateResponseAgentsItemToolsItemSourceCode",
    "TemplatesCreateAgentsFromTemplateResponseAgentsItemToolsItemSourceCodeItem",
    "TemplatesCreateAgentsFromTemplateResponseAgentsItemToolsItemSourceType",
    "TemplatesCreateAgentsFromTemplateResponseAgentsItemToolsItemSourceTypeItem",
    "TemplatesCreateAgentsFromTemplateResponseAgentsItemToolsItemToolType",
    "TemplatesCreateAgentsFromTemplateResponseAgentsItemUpdatedAt",
    "TemplatesCreateAgentsFromTemplateResponseAgentsItemUpdatedAtItem",
]
