# This file was auto-generated by Fern from our API Definition.

import typing

TemplatesCreateAgentsFromTemplateResponseAgentsItemMessageIdsItem = typing.Union[typing.List[str], typing.Optional[str]]
